@@ -3,6 +3,7 @@
 #include <config.h>
 #include "panel.h"
 #include <gnome.h>
+#include "dialog.h"
 #include "global.h"
 #include "file.h"
 #include "filegui.h"
@@ -242,12 +243,9 @@ file_progress_show (FileOpContext *ctx, long done, long total)
         
         if (total > 0) {
                 perc = (double) done / (double) total;
-                snprintf (count, 9, "%d%%", (gint) (100.0 * perc));
+                snprintf (count, 9, "%3d%% ", (gint) (100.0 * perc));
                 gtk_label_set_text (GTK_LABEL (ui->file_label), count);
-                gtk_progress_bar_update (GTK_PROGRESS_BAR (ui->byte_prog), perc);
-        } else
-                gtk_progress_bar_update (GTK_PROGRESS_BAR (ui->byte_prog), 0.0);
-
+        }
         while (gtk_events_pending ())
                 gtk_main_iteration ();
 	return FILE_CONT;
@@ -270,7 +268,7 @@ file_progress_show_count (FileOpContext *ctx, long done, long total)
         if (ui->aborting)
                 return FILE_ABORT;
 
-        snprintf (count, 13, "%d/%d", done, total);
+        snprintf (count, 13, "%d/%d ", done, total);
         gtk_label_set_text (GTK_LABEL (ui->count_label), count);
         while (gtk_events_pending ())
                 gtk_main_iteration ();
@@ -294,7 +292,11 @@ file_progress_show_bytes (FileOpContext *ctx, double done, double total)
         if (ui->aborting)
                 return FILE_ABORT;
 
-        perc = done / total;
+        if (total == 0.0)
+                perc = 1.0;
+        else
+                perc = done / total;
+
         gtk_progress_bar_update (GTK_PROGRESS_BAR (ui->byte_prog), CLAMP (perc, 0.0, 1.0));
 
         while (gtk_events_pending ())
@@ -893,10 +895,10 @@ file_op_context_create_ui (FileOpContext *ctx, FileOperation op, int with_eta)
         ui->count_label = GTK_OBJECT (gtk_label_new (""));
         gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (ui->count_label), FALSE, FALSE, 0);
 
-        gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_(" is ")), FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_("is ")), FALSE, FALSE, 0);
         ui->file_label = gtk_label_new ("");
         gtk_box_pack_start (GTK_BOX (hbox), ui->file_label, FALSE, FALSE, 0);
-        gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_(" Done.")), FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (hbox), gtk_label_new (_("done.")), FALSE, FALSE, 0);
         gtk_container_add (GTK_CONTAINER (alignment), hbox);
 
         gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (ui->op_win)->vbox),
