@@ -434,7 +434,7 @@ static GtkWidget *
 generate_icon_sel (GnomeFilePropertyDialog *fp_dlg)
 {
 	GtkWidget *retval;
-	const gchar *icon;
+	gchar *icon;
 	
 	retval = gnome_icon_entry_new ("gmc_file_icon", "Select an Icon");
 	icon = g_strdup (gicon_get_filename_for_icon (fp_dlg->im));
@@ -911,7 +911,7 @@ perm_ownership_new (GnomeFilePropertyDialog *fp_dlg)
 	GtkWidget *frame;
 	GtkWidget *table;
 
-	frame = gtk_frame_new ("File ownership");
+	frame = gtk_frame_new (_("File ownership"));
 
 	table = gtk_table_new (2, 2, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (table), 6);
