@@ -2,8 +2,14 @@
 #define __GSCREEN_H
 
 
+/* GnomeUIInfo information for view types */
+extern GnomeUIInfo panel_view_menu_uiinfo[];
+extern GnomeUIInfo panel_view_toolbar_uiinfo[];
+
 WPanel *create_container (Dlg_head *h, char *str, char *geometry);
 
+void copy_uiinfo_widgets (GnomeUIInfo *uiinfo, gpointer **dest);
+
 typedef struct {
 	int splitted;
 	
@@ -16,4 +22,5 @@ typedef struct {
 extern PanelContainer *current_panel_ptr, *other_panel_ptr;
 extern GList *containers;
 
+
 #endif /* __GSCREEN_H */
