@@ -76,7 +76,7 @@
 #include "user.h"		/* expand_format */
 #include "../vfs/vfs.h"
 
-/* "$Id: util.c,v 1.22 1999/03/18 13:40:26 timur Exp $" */
+/* "$Id: util.c,v 1.23 1999/03/29 05:07:03 norbert Exp $" */
 
 char app_text [] = "Midnight-Commander";
 
@@ -110,7 +110,7 @@ int is_printable (int c)
 	    if (xterm_flag)
 	        return xterm_printable [c];
 	    else
-	        return (c > 31 && c != 127);
+	        return (c > 31 && c != 127 && c != 155);
 	} else
 	    return ((c >31 && c < 127) || c >= 160);
     } else
