@@ -918,12 +918,12 @@ static int extfs_init (vfs *me)
 
 	if ((c = strchr (key, '\n'))){
 	    *c = 0;
-	    c = &key [strlen (key)-1];
+	    c = &key [strlen (key) - 1];
 	} else {
-	    c = &key;
+	    c = key;
 	}
-	extfs_need_archive [extfs_no] = !(*c==':');
-	if (*c==':')
+	extfs_need_archive [extfs_no] = !(*c == ':');
+	if (*c == ':')
 		*c = 0;
 	if (!(*key))
 	    continue;
